summaryrefslogtreecommitdiffstats
path: root/cpukit/score/cpu/m68k/rtems/score
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/score/cpu/m68k/rtems/score')
-rw-r--r--cpukit/score/cpu/m68k/rtems/score/cpu.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/cpukit/score/cpu/m68k/rtems/score/cpu.h b/cpukit/score/cpu/m68k/rtems/score/cpu.h
index a9a152cd2e..2353332620 100644
--- a/cpukit/score/cpu/m68k/rtems/score/cpu.h
+++ b/cpukit/score/cpu/m68k/rtems/score/cpu.h
@@ -165,14 +165,24 @@ typedef struct {
#endif
/*
* The following structure defines the set of information saved
* on the current stack by RTEMS upon receipt of each interrupt.
*/
typedef struct {
- unsigned32 TBD; /* XXX Fix for this CPU */
+ unsigned32 vecnum; /* vector number */
} CPU_Interrupt_frame;
+typedef struct {
+ unsigned32 vecnum; /* vector number */
+ unsigned32 sr; /* status register */
+ unsigned32 pc; /* program counter */
+ unsigned32 d0, d1, d2, d3, d4, d5, d6, d7;
+ unsigned32 a0, a1, a2, a3, a4, a5, a6, a7;
+} CPU_Exception_frame;
+
/*
* The following table contains the information required to configure
* the m68k specific parameters.
@@ -165,14 +165,24 @@ typedef struct {
#endif
/*
- * The following structure defines the set of information saved
- * on the current stack by RTEMS upon receipt of each interrupt.
+ * The following structures define the set of information saved
+ * on the current stack by RTEMS upon receipt of each exc/interrupt.
+ * These are not used by m68k handlers.
+ * The exception frame is for rdbg.
*/
typedef struct {